summaryrefslogtreecommitdiff
path: root/include/llvm/Function.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/llvm/Function.h')
-rw-r--r--include/llvm/Function.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/include/llvm/Function.h b/include/llvm/Function.h
index 9954418ab8..04e0535ace 100644
--- a/include/llvm/Function.h
+++ b/include/llvm/Function.h
@@ -148,12 +148,12 @@ public:
///
void setParamAttrs(const PAListPtr &attrs) { ParamAttrs = attrs; }
- /// hasCollector/getCollector/setCollector/clearCollector - The name of the
- /// garbage collection algorithm to use during code generation.
- bool hasCollector() const;
- const char *getCollector() const;
- void setCollector(const char *Str);
- void clearCollector();
+ /// hasGC/getGC/setGC/clearGC - The name of the garbage collection algorithm
+ /// to use during code generation.
+ bool hasGC() const;
+ const char *getGC() const;
+ void setGC(const char *Str);
+ void clearGC();
/// @brief Determine whether the function has the given attribute.
bool paramHasAttr(unsigned i, ParameterAttributes attr) const {